@@ -121,6 +121,17 @@ def link_new_code():
     with cd('/data/deploy'):
         sudo('(ls -t|head -n 5;ls)|sort|uniq -u|xargs rm -rf')
 
+@task
+def pip_install():
+    with cd('/data/deploy/current'):
+        sudo('pip install -r requirements.txt')
+
+@task
+#https://docs.djangoproject.com/en/1.8/ref/django-admin/#django-admin-check
+def django_check():
+    with cd('/data/deploy'):
+        sudo('python manage.py check')
+
 @task
 def remote_inflate_code():
     unpack_code()
@@ -143,6 +154,7 @@ def codeversioner():
 def deploycode(branch):
     tar_from_git(branch)
     remote_inflate_code()
+    pip_install()
 
 @task
 def dbmigrate_docker(containerid,codepath='/data/deploy/current'):
